'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _s3PolicyV = require('s3-policy-v4');

var _s3PolicyV2 = _interopRequireDefault(_s3PolicyV);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var assert = function assert(value, message) {
  if (value == null) throw new Error(message);
};

exports.default = function (config) {
  var keyPrefix = config.NAME_PREFIX;
  var region = config.REGION;
  var bucket = config.BUCKET;
  var accessKey = config.ACCESS_KEY_ID;
  var secretKey = config.SECRET_ACCESS_KEY;


  if (!keyPrefix) keyPrefix = '';

  assert(region, "'REGION' must be provided");
  assert(bucket, "'BUCKET' must be provided");
  assert(accessKey, "'ACCESS_KEY_ID' must be provided");
  assert(secretKey, "'SECRET_ACCESS_KEY' must be provided");

  var endPoint = 'https://' + bucket + '.s3.amazonaws.com';
  var urlPrefix = endPoint + '/';

  return function (req, res, next) {
    var _req$body = req.body;
    var name = _req$body.name;
    var contentType = _req$body.contentType;


    if (!name) return next(new Error('name is required!'));
    if (!contentType) return next(new Error('contentType is required!'));

    var key = keyPrefix + name;

    var policy = _s3PolicyV2.default.generate({
      key: key,
      bucket: bucket,
      contentType: contentType,
      region: region,
      accessKey: accessKey,
      secretKey: secretKey
    });

    // successActionStatus: '',
    res.json({
      endPoint: endPoint,
      url: urlPrefix + key,
      policy: policy
    });
  };
};